/* ***** BEGIN LICENSE BLOCK *****
 * FW4SPL - Copyright (C) IRCAD, 2009-2015.
 * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
 * published by the Free Software Foundation.
 * ****** END LICENSE BLOCK ****** */

#ifndef __FWRUNTIME_IO_NAMESPACE_HPP__
#define __FWRUNTIME_IO_NAMESPACE_HPP__


namespace fwRuntime
{
/**
 * @brief       The namespace fwRuntime::io contains classes to read and perform profile file  .
 * @namespace   fwRuntime::io
 *
 * @date        2009-2010.
 *
 */
namespace io
{

}
}
#endif /* __FWRUNTIME_IO_NAMESPACE_HPP__ */
